==> percona-xtradb-cluster_8.0.34-26.orig.tar.gz: Percona-XtraDB-Cluster-8.0.34-26/percona-xtradb-cluster-galera/galera/src/CMakeFiles/galera.dir/DependInfo.cmake <==
# The set of languages for which implicit dependencies are needed:
set(CMAKE_DEPENDS_LANGUAGES
  "CXX"
  )
# The set of files for implicit dependencies of each language:
set(CMAKE_DEPENDS_CHECK_CXX
  "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/galera/src/certification.cpp" "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/galera/src/CMakeFiles/galera.dir/certification.cpp.o"
  "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/galera/src/data_set.cpp" "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/galera/src/CMakeFiles/galera.dir/data_set.cpp.o"
  "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/galera/src/galera_info.cpp" "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/galera/src/CMakeFiles/galera.dir/galera_info.cpp.o"
  "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/galera/src/galera_service_thd.cpp" "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/galera/src/CMakeFiles/galera.dir/galera_service_thd.cpp.o"
  "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/galera/src/galera_view.cpp" "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/galera/src/CMakeFiles/galera.dir/galera_view.cpp.o"
  "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/galera/src/gcs_action_source.cpp" "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/galera/src/CMakeFiles/galera.dir/gcs_action_source.cpp.o"
  "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/galera/src/gcs_dummy.cpp" "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/galera/src/CMakeFiles/galera.dir/gcs_dummy.cpp.o"
  "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/galera/src/ist.cpp" "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/galera/src/CMakeFiles/galera.dir/ist.cpp.o"
  "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/galera/src/ist_proto.cpp" "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/galera/src/CMakeFiles/galera.dir/ist_proto.cpp.o"
  "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/galera/src/key_entry_os.cpp" "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/galera/src/CMakeFiles/galera.dir/key_entry_os.cpp.o"
  "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/galera/src/key_set.cpp" "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/galera/src/CMakeFiles/galera.dir/key_set.cpp.o"
  "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/galera/src/mapped_buffer.cpp" "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/galera/src/CMakeFiles/galera.dir/mapped_buffer.cpp.o"
  "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/galera/src/replicator.cpp" "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/galera/src/CMakeFiles/galera.dir/replicator.cpp.o"
  "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/galera/src/replicator_smm.cpp" "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/galera/src/CMakeFiles/galera.dir/replicator_smm.cpp.o"
  "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/galera/src/replicator_smm_params.cpp" "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/galera/src/CMakeFiles/galera.dir/replicator_smm_params.cpp.o"
  "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/galera/src/replicator_smm_stats.cpp" "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/galera/src/CMakeFiles/galera.dir/replicator_smm_stats.cpp.o"
  "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/galera/src/replicator_str.cpp" "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/galera/src/CMakeFiles/galera.dir/replicator_str.cpp.o"
  "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/galera/src/saved_state.cpp" "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/galera/src/CMakeFiles/galera.dir/saved_state.cpp.o"
  "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/galera/src/trx_handle.cpp" "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/galera/src/CMakeFiles/galera.dir/trx_handle.cpp.o"
  "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/galera/src/write_set.cpp" "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/galera/src/CMakeFiles/galera.dir/write_set.cpp.o"
  "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/galera/src/write_set_ng.cpp" "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/galera/src/CMakeFiles/galera.dir/write_set_ng.cpp.o"
  "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/galera/src/wsdb.cpp" "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/galera/src/CMakeFiles/galera.dir/wsdb.cpp.o"
  "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/galera/src/wsrep_params.cpp" "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/galera/src/CMakeFiles/galera.dir/wsrep_params.cpp.o"
  )
set(CMAKE_CXX_COMPILER_ID "GNU")

# Preprocessor definitions for this target.
set(CMAKE_TARGET_DEFINITIONS_CXX
  "BOOST_DATE_TIME_POSIX_TIME_STD_CONFIG=1"
  "BOOST_NO_CXX98_FUNCTION_BASE"
  "GALERA_HAVE_SSL"
  "HAVE_ASIO_HPP"
  "HAVE_BOOST_SHARED_PTR_HPP"
  "HAVE_BYTESWAP_H"
  "HAVE_COMMON_H"
  "HAVE_CONFIG_H"
  "HAVE_ENDIAN_H"
  "HAVE_PSI_INTERFACE=1"
  "HAVE_STD_ARRAY"
  "HAVE_STD_UNORDERED_MAP"
  "LZ4_DISABLE_DEPRECATE_WARNINGS"
  "NDEBUG"
  "OPENSSL_HAS_SET_ECDH_AUTO"
  "PXC"
  "WSREP_PS_VAR_VALUE_BUFF_SIZE=4096"
  "_FILE_OFFSET_BITS=64"
  "_GNU_SOURCE"
  "_USE_MATH_DEFINES"
  "__STDC_FORMAT_MACROS"
  "__STDC_LIMIT_MACROS"
  )

# The include file search paths:
set(CMAKE_CXX_TARGET_INCLUDE_PATH
  "wsrep-lib/include"
  "wsrep-lib/wsrep-API/v26"
  "."
  "include"
  "percona-xtradb-cluster-galera"
  "percona-xtradb-cluster-galera/common"
  "percona-xtradb-cluster-galera/galera/src"
  "percona-xtradb-cluster-galera/galerautils/src"
  "percona-xtradb-cluster-galera/gcache/src"
  "percona-xtradb-cluster-galera/gcomm/src"
  "percona-xtradb-cluster-galera/gcs/src"
  "percona-xtradb-cluster-galera/wsrep/src"
  "extra/protobuf/protobuf-3.19.4/src"
  "percona-xtradb-cluster-galera/asio"
  )

# Targets to which this target links.
set(CMAKE_TARGET_LINKED_INFO_FILES
  "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/gcs/src/CMakeFiles/gcs.dir/DependInfo.cmake"
  "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/gcomm/src/CMakeFiles/gcomm.dir/DependInfo.cmake"
  "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/gcache/src/CMakeFiles/gcache.dir/DependInfo.cmake"
  "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/galerautils/src/CMakeFiles/galerautilsxx.dir/DependInfo.cmake"
  "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/galerautils/src/CMakeFiles/galerautils.dir/DependInfo.cmake"
  "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/galerautils/src/CMakeFiles/galerautils_hw_crc32c.dir/DependInfo.cmake"
  "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/galerautils/src/CMakeFiles/galerautils_log.dir/DependInfo.cmake"
  )

# Fortran module output directory.
set(CMAKE_Fortran_TARGET_MODULE_DIR "")

==> percona-xtradb-cluster_8.0.39-30.orig.tar.gz: Percona-XtraDB-Cluster-8.0.39-30/percona-xtradb-cluster-galera/galera/src/CMakeFiles/galera.dir/DependInfo.cmake <==
# The set of languages for which implicit dependencies are needed:
set(CMAKE_DEPENDS_LANGUAGES
  "CXX"
  )
# The set of files for implicit dependencies of each language:
set(CMAKE_DEPENDS_CHECK_CXX
  "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/galera/src/certification.cpp" "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/galera/src/CMakeFiles/galera.dir/certification.cpp.o"
  "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/galera/src/data_set.cpp" "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/galera/src/CMakeFiles/galera.dir/data_set.cpp.o"
  "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/galera/src/galera_info.cpp" "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/galera/src/CMakeFiles/galera.dir/galera_info.cpp.o"
  "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/galera/src/galera_service_thd.cpp" "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/galera/src/CMakeFiles/galera.dir/galera_service_thd.cpp.o"
  "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/galera/src/galera_view.cpp" "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/galera/src/CMakeFiles/galera.dir/galera_view.cpp.o"
  "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/galera/src/gcs_action_source.cpp" "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/galera/src/CMakeFiles/galera.dir/gcs_action_source.cpp.o"
  "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/galera/src/gcs_dummy.cpp" "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/galera/src/CMakeFiles/galera.dir/gcs_dummy.cpp.o"
  "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/galera/src/ist.cpp" "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/galera/src/CMakeFiles/galera.dir/ist.cpp.o"
  "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/galera/src/ist_proto.cpp" "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/galera/src/CMakeFiles/galera.dir/ist_proto.cpp.o"
  "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/galera/src/key_data.cpp" "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/galera/src/CMakeFiles/galera.dir/key_data.cpp.o"
  "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/galera/src/key_entry_os.cpp" "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/galera/src/CMakeFiles/galera.dir/key_entry_os.cpp.o"
  "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/galera/src/key_set.cpp" "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/galera/src/CMakeFiles/galera.dir/key_set.cpp.o"
  "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/galera/src/mapped_buffer.cpp" "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/galera/src/CMakeFiles/galera.dir/mapped_buffer.cpp.o"
  "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/galera/src/replicator.cpp" "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/galera/src/CMakeFiles/galera.dir/replicator.cpp.o"
  "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/galera/src/replicator_smm.cpp" "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/galera/src/CMakeFiles/galera.dir/replicator_smm.cpp.o"
  "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/galera/src/replicator_smm_params.cpp" "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/galera/src/CMakeFiles/galera.dir/replicator_smm_params.cpp.o"
  "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/galera/src/replicator_smm_stats.cpp" "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/galera/src/CMakeFiles/galera.dir/replicator_smm_stats.cpp.o"
  "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/galera/src/replicator_str.cpp" "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/galera/src/CMakeFiles/galera.dir/replicator_str.cpp.o"
  "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/galera/src/saved_state.cpp" "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/galera/src/CMakeFiles/galera.dir/saved_state.cpp.o"
  "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/galera/src/trx_handle.cpp" "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/galera/src/CMakeFiles/galera.dir/trx_handle.cpp.o"
  "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/galera/src/write_set.cpp" "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/galera/src/CMakeFiles/galera.dir/write_set.cpp.o"
  "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/galera/src/write_set_ng.cpp" "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/galera/src/CMakeFiles/galera.dir/write_set_ng.cpp.o"
  "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/galera/src/wsdb.cpp" "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/galera/src/CMakeFiles/galera.dir/wsdb.cpp.o"
  "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/galera/src/wsrep_params.cpp" "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/galera/src/CMakeFiles/galera.dir/wsrep_params.cpp.o"
  )
set(CMAKE_CXX_COMPILER_ID "GNU")

# Preprocessor definitions for this target.
set(CMAKE_TARGET_DEFINITIONS_CXX
  "BOOST_BIND_GLOBAL_PLACEHOLDERS=1"
  "BOOST_DATE_TIME_POSIX_TIME_STD_CONFIG=1"
  "BOOST_NO_CXX98_FUNCTION_BASE"
  "GALERA_HAVE_SSL"
  "HAVE_ASIO_HPP"
  "HAVE_BOOST_SHARED_PTR_HPP"
  "HAVE_BYTESWAP_H"
  "HAVE_COMMON_H"
  "HAVE_CONFIG_H"
  "HAVE_ENDIAN_H"
  "HAVE_PSI_INTERFACE=1"
  "HAVE_STD_ARRAY"
  "HAVE_STD_UNORDERED_MAP"
  "LZ4_DISABLE_DEPRECATE_WARNINGS"
  "NDEBUG"
  "OPENSSL_HAS_SET_ECDH_AUTO"
  "PXC"
  "WSREP_PS_VAR_VALUE_BUFF_SIZE=4096"
  "_FILE_OFFSET_BITS=64"
  "_GNU_SOURCE"
  "_USE_MATH_DEFINES"
  "_XOPEN_SOURCE=600"
  "__STDC_FORMAT_MACROS"
  "__STDC_LIMIT_MACROS"
  )

# The include file search paths:
set(CMAKE_CXX_TARGET_INCLUDE_PATH
  "wsrep-lib/include"
  "wsrep-lib/wsrep-API/v26"
  "."
  "include"
  "percona-xtradb-cluster-galera"
  "percona-xtradb-cluster-galera/common"
  "percona-xtradb-cluster-galera/galera/src"
  "percona-xtradb-cluster-galera/galerautils/src"
  "percona-xtradb-cluster-galera/gcache/src"
  "percona-xtradb-cluster-galera/gcomm/src"
  "percona-xtradb-cluster-galera/gcs/src"
  "percona-xtradb-cluster-galera/wsrep/src"
  "extra/protobuf/protobuf-24.4/src"
  "percona-xtradb-cluster-galera/asio"
  )

# Targets to which this target links.
set(CMAKE_TARGET_LINKED_INFO_FILES
  "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/gcs/src/CMakeFiles/gcs.dir/DependInfo.cmake"
  "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/gcomm/src/CMakeFiles/gcomm.dir/DependInfo.cmake"
  "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/gcache/src/CMakeFiles/gcache.dir/DependInfo.cmake"
  "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/galerautils/src/CMakeFiles/galerautilsxx.dir/DependInfo.cmake"
  "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/galerautils/src/CMakeFiles/galerautils.dir/DependInfo.cmake"
  "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/galerautils/src/CMakeFiles/galerautils_hw_crc32c.dir/DependInfo.cmake"
  "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/percona-xtradb-cluster-galera/galerautils/src/CMakeFiles/galerautils_log.dir/DependInfo.cmake"
  )

# Fortran module output directory.
set(CMAKE_Fortran_TARGET_MODULE_DIR "")
